# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-09-04 09:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_datawatch', '0002_auto_20160903_2149'),
    ]

    operations = [
        migrations.CreateModel(
            name='CheckExecution',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.TextField(unique=True, verbose_name='Check module slug')),
                ('last_run', models.DateTimeField(verbose_name='Last run')),
            ],
        ),
        migrations.AlterField(
            model_name='check',
            name='acknowledged_reason',
            field=models.TextField(blank=True, verbose_name='Acknowledge reason'),
        ),
    ]
