# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-09-03 21:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_datawatch', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='check',
            name='acknowledged_reason',
            field=models.TextField(blank=True, verbose_name='Acknowledged until'),
        ),
        migrations.AlterField(
            model_name='check',
            name='status',
            field=models.IntegerField(choices=[(0, 'Unknown'), (1, 'OK'), (2, 'Warning'), (3, 'Critical')], default=0, verbose_name='Status'),
        ),
    ]
